<?php
/* 
 * See readme.txt for explanation as to how "sg-x", "push-x" and "pull-x"
 * classes work to define layout.
 */

// Auto-rebuild the theme registry on every pageload, depending upon settings
if (theme_get_setting('squaregrid_rebuild_registry') == '1') {
  // Rebuild .info data.
  system_rebuild_theme_data();
  // Rebuild theme registry.
  drupal_theme_rebuild();
}

// Include file to set message reminder when registry rebuild is set
function squaregrid_theme(&$existing, $type, $theme, $path) {
  include_once './' . drupal_get_path('theme', 'squaregrid') . '/template.theme-registry.inc';
  return _squaregrid_theme($existing, $type, $theme, $path);
}

// Define page region class variables for whether 1 or 2 sidebars
function squaregrid_preprocess_page(&$variables, $hook) {
  $page = $variables['page'];

  // if both sidebars are present
  if ($page['sidebar_first'] && $page['sidebar_second']) {
    $variables['class_content'] = t('sg-17 push-11');
    $variables['class_sidebar_first'] = t('sg-10 pull-18');
    $variables['class_sidebar_second'] = t('sg-6');
  }

  // if only first sidebar is present
  if ($page['sidebar_first'] && !$page['sidebar_second']) {
    $variables['class_content'] = t('sg-21 push-14');
    $variables['class_sidebar_first'] = t('sg-13 pull-22');
  }

  // if only second sidebar is present
  if ($page['sidebar_second'] && !$page['sidebar_first']) {
    $variables['class_content'] = t('sg-21');
    $variables['class_sidebar_second'] = t('sg-13');
  }
  
  // if no sidebar is present
  if (!$page['sidebar_first'] && !$page['sidebar_second']) {
    $variables['class_content'] = t('sg-35');
  }
  
// For easy printing of basic page elements
  // Branding
  $variables['logo_img'] = '';
  if (!empty($variables['logo'])) {
    $variables['logo_img'] = theme('image__logo', array(
      'path'  => $variables['logo'],
      'alt'   => t('Site Logo'),
    ));
  }
  $variables['linked_logo_img']  = '';
  if (!empty($variables['logo_img'])) {
    $variables['linked_logo_img'] = l($variables['logo_img'], '<front>', array(
      'html' => TRUE,
      'attributes' => array(
        'rel'   => 'home',
        'title' => t('Home'),
      ),
    ));
  }
  $variables['linked_site_name'] = '';
  if (!empty($variables['site_name'])) {
    $variables['linked_site_name'] = l($variables['site_name'], '<front>', array(
      'attributes' => array(
        'rel'   => 'home',
        'title' => t('Home'),
      ),
    ));
  }
  // Site navigation links.
  $variables['main_menu_links'] = theme('links__system_main_menu', array(
    'links' => $variables['main_menu'],
    'attributes' => array(
      'id'    => 'main-menu',
      'class' => array('main-menu', 'inline'),
    ),
    'heading' => array(
      'text'  => t('Main menu'),
      'level' => 'h2',
      'class' => array('element-invisible'),
    ),
  ));
  $variables['secondary_menu_links'] = theme('links__system_secondary_menu', array(
    'links' => $variables['secondary_menu'],
    'attributes' => array(
      'id'    => 'secondary-menu',
      'class' => array('secondary-menu', 'inline', 'hello'),
    ),
    'heading' => array(
      'text'  => t('Secondary menu'),
      'level' => 'h2',
      'class' => array('element-invisible'),
    ),
  ));

}

// Add helpful classes to node arrays
function squaregrid_preprocess_node(&$variables, $hook) {
  // Add an unpublished variable
  $variables['unpublished'] = (!$variables['status']) ? TRUE : FALSE;

  // Add a class for user's own node
  if ($variables['uid'] && $variables['uid'] == $GLOBALS['user']->uid) {
    $variables['classes_array'][] = 'node-by-viewer';
  }

  $variables['title_attributes_array']['class'][] = 'node-title';
}


// Add helpful classes to comment arrays
function squaregrid_preprocess_comment(&$variables, $hook) {

  // If comment subjects are disabled, don't display them.
  if (variable_get('comment_subject_field_' . $variables['node']->type, 1) == 0) {
    $variables['title'] = '';
  }

  // Add zebra classes
  if ($variables['id'] == 1) {
    $variables['classes_array'][] = 'first';
  }
  if ($variables['id'] == $variables['node']->comment_count) {
    $variables['classes_array'][] = 'last';
  }
  $variables['classes_array'][] = $variables['zebra'];

  // Mark title with comment title class
  $variables['title_attributes_array']['class'][] = 'comment-title';
}


// Add helpful classes to regions
function squaregrid_preprocess_region(&$variables, $hook) {
  // Sidebar regions get some extra classes and a common template suggestion.
  if (strpos($variables['region'], 'sidebar_') === 0) {
    $variables['classes_array'][] = 'supplementary-content';
  }
}

// Load CSS files depending upon Theme Settings
// See theme-settings.php
function squaregrid_preprocess_html(&$vars) {
// first load reset and default css
  drupal_add_css(drupal_get_path('theme', 'squaregrid') . '/styles/reset.css', array('group' => CSS_THEME, 'preprocess' => TRUE, 'every_page' => TRUE, 'weight' => '-10'));
  drupal_add_css(drupal_get_path('theme', 'squaregrid') . '/styles/default.css', array('group' => CSS_THEME, 'preprocess' => TRUE, 'every_page' => TRUE, 'weight' => '-9'));
  // if responsive_support is checked
  if (theme_get_setting('responsive_support') == '1') {
  // then load the default grid css file
    drupal_add_css(drupal_get_path('theme', 'squaregrid') . '/styles/default-grid.css', array('group' => CSS_THEME, 'preprocess' => TRUE, 'every_page' => TRUE, 'weight' => '-8'));
    // if 770 is checked
    if (theme_get_setting('smallgrid')) {
      drupal_add_css(drupal_get_path('theme', 'squaregrid') . '/styles/smallgrid.css', array('group' => CSS_THEME, 'preprocess' => TRUE, 'every_page' => TRUE, 'weight' => '-7'));
    }
    // if 980 set, load squaregrid.css
    if (theme_get_setting('squaregrid')) {
      drupal_add_css(drupal_get_path('theme', 'squaregrid') . '/styles/squaregrid.css', array('group' => CSS_THEME, 'preprocess' => TRUE, 'every_page' => TRUE, 'weight' => '-6'));
    }
    // if 1190 set, load sgw1190.css
    if (theme_get_setting('sgw1190')) {
      drupal_add_css(drupal_get_path('theme', 'squaregrid') . '/styles/sgw1190.css', array('group' => CSS_THEME, 'preprocess' => TRUE, 'every_page' => TRUE, 'weight' => '-5'));
    }
    // if 1400 set, load sgw1400.css
    // ** CSS TBD - theme-setting disabled **
    if (theme_get_setting('sgw1400')) {
      drupal_add_css(drupal_get_path('theme', 'squaregrid') . '/styles/sgw1400.css', array('group' => CSS_THEME, 'preprocess' => TRUE, 'every_page' => TRUE, 'weight' => '-4'));
    }

    // also load one selected stylesheet for IE only
    // load stylesheet only on IE6-8 browsers
    switch (theme_get_setting('ie_select')) {
      case 'ie770':
        drupal_add_css(drupal_get_path('theme', 'squaregrid') .  '/styles/static770.css', array('weight' => CSS_THEME, 'browsers' => array('IE' => 'lte IE 8', '!IE' => FALSE), 'preprocess' => FALSE));
        break;
      case 'ie980':
        drupal_add_css(drupal_get_path('theme', 'squaregrid') .  '/styles/static980.css', array('weight' => CSS_THEME, 'browsers' => array('IE' => 'lte IE 8', '!IE' => FALSE), 'preprocess' => FALSE));
        break;
      case 'ie1190':
        drupal_add_css(drupal_get_path('theme', 'squaregrid') .  '/styles/static1190.css', array('weight' => CSS_THEME, 'browsers' => array('IE' => 'lte IE 8', '!IE' => FALSE), 'preprocess' => FALSE));
        break;
    } // end switch

  } // end if responsive_support

  // else: (i.e. !responsive_support)
  else {

    // load the one universal stylesheet selected for all browsers
    switch (theme_get_setting('static_select')) {
      case 'static770':
        drupal_add_css(drupal_get_path('theme', 'squaregrid') . '/styles/static770.css', array('group' => CSS_THEME, 'preprocess' => TRUE, 'every_page' => TRUE, 'weight' => '-1'));
        break;
      case 'static980':
        drupal_add_css(drupal_get_path('theme', 'squaregrid') . '/styles/static980.css', array('group' => CSS_THEME, 'preprocess' => TRUE, 'every_page' => TRUE, 'weight' => '-1'));
        break;
      case 'static1190':
        drupal_add_css(drupal_get_path('theme', 'squaregrid') . '/styles/static1190.css', array('group' => CSS_THEME, 'preprocess' => TRUE, 'every_page' => TRUE, 'weight' => '-1'));
        break;
    } // end switch

  } // end if else responsive_support

  // If "show grid" is selected in theme settings:
  // set showgrid variable for html.tpl.php AND
  // load the global showgrid stylesheet
  if (theme_get_setting('showgrid')) {
    $vars['grid'] = 'showgrid';
    drupal_add_css(drupal_get_path('theme', 'squaregrid') . '/styles/showgrid.css', array('group' => CSS_THEME, 'preprocess' => TRUE, 'every_page' => TRUE, 'weight' => '6'));
  }
  else {
    $vars['grid'] = 'nogrid';
  } // end if/else showgrid

} // end function squaregrid_preprocess_html