<?php
// Responsive design support settings
function squaregrid_form_system_theme_settings_alter(&$form, &$form_state) {

// Fieldgroup
$form['responsive'] = array(
  '#type'   => 'fieldset',
  '#title'  => t('Theme Grid Settings'),
  '#description' => t('Select how you want your theme to behave in various browser window/screen sizes.'),
  '#weight' => '-20',
);

  // Checkbox to enable responsive support. Enabled is default
  $form['responsive']['responsive_support'] = array(
    '#type' => 'checkbox',
    '#title' => t('Support mobile-first responsive design?'),
    '#default_value' => theme_get_setting('responsive_support'),
    '#description' => t('Enable to configure responsive design support. Disable if you want a single grid width setting for all displays. Additional configuration options are available, depending upon this setting.'),
  );

  // Field subgrouping - visible only for responsive options
  $form['responsive']['responsive_options'] = array(
    '#type'   => 'fieldset',
    '#title'  => t('Responsive Design Options'),
    '#description' => t('<em>You have enabled responsive design support. Adjust settings below for various browsers.</em>'),
    '#states' => array(
      'invisible' => array(
        ':input[name="responsive_support"]' => array('checked' => FALSE),
      ),
    ),
  );

  // If responsive_options, choose standards-supporting browser support options
    $form['responsive']['responsive_options']['standards_browser_options'] = array(
      '#type'   => 'fieldset',
      '#title'  => t('Grid Settings for Standards-supporting Browsers'),
      '#description' => t('The largest grid enabled below that fits within the screen width will govern display. On screen widths smaller than the smallest enabled grid, pages are loaded in single-column display for readability. <em>If no grids are selected, no grid css will be loaded at all and everything will be single-column.</em><p><strong>Choose one or more grids to govern responsive display:</strong></p>'),
      '#states' => array(
        'invisible' => array(
          ':input[name="responsive_support"]' => array('checked' => FALSE),
        ),
      ),
    );

    // Checkbox to enable responsive 770px grid
    $form['responsive']['responsive_options']['standards_browser_options']['smallgrid'] = array(
      '#type' => 'checkbox',
      '#title' => t('770px grid'),
      '#default_value' => theme_get_setting('smallgrid'),
      '#states' => array(
        'invisible' => array(
          ':input[name="responsive_support"]' => array('checked' => FALSE),
        ),
      ),
    );

    // Checkbox to enable responsive 980px grid
    $form['responsive']['responsive_options']['standards_browser_options']['squaregrid'] = array(
      '#type' => 'checkbox',
      '#title' => t('980px grid'),
      '#default_value' => theme_get_setting('squaregrid'),
      '#states' => array(
        'invisible' => array(
          ':input[name="responsive_support"]' => array('checked' => FALSE),
        ),
      ),
    );

    // Checkbox to enable responsive 1190px grid
    $form['responsive']['responsive_options']['standards_browser_options']['sgw1190'] = array(
      '#type' => 'checkbox',
      '#title' => t('1190px grid'),
      '#default_value' => theme_get_setting('sgw1190'),
      '#states' => array(
        'invisible' => array(
          ':input[name="responsive_support"]' => array('checked' => FALSE),
        ),
      ),
    );
  // This is visible only if responsive_support is un-checked
  $form['responsive']['static_options'] = array(
    '#type'   => 'fieldset',
    '#title'  => t('Select universal grid size'),
    '#description' => t('<em>You have disabled responsive design support.</em>'),
    '#states' => array(
      'invisible' => array(
        ':input[name="responsive_support"]' => array('checked' => TRUE),
        ),
    ),
  );

    // Single-select for static grid support on all browsers
    $form['responsive']['static_options']['static_select'] = array(
      '#type' => 'radios',
      '#title' => t('Choose the grid to use for all screen sizes:'),
      '#options' => array(
        'static770'  => t('770px grid'),
        'static980'  => t('980px grid'),
        'static1190' => t('1190px grid'),
        ),
      '#default_value' => theme_get_setting('static_select'),
    );

  // If responsive_options, choose IE-only support options
    $form['responsive']['responsive_options']['ie_grid_options'] = array(
      '#type'   => 'fieldset',
      '#title'  => t('Grid Settings for Internet Explorer 6-8'),
      '#description' => t('Internet Explorer 6, 7 and 8 do not natively support the media queries utilized for responsive design. Choose what grid should be loaded for IE6-8.'),
      '#states' => array(
        'invisible' => array(
          ':input[name="responsive_support"]' => array('checked' => FALSE),
        ),
      ),
    );

    // Selection for IE support if responsive_support is selected
    $form['responsive']['responsive_options']['ie_grid_options']['ie_grid_select'] = array(
      '#type' => 'radios',
      '#title' => t('Always display on IE6-8 using:'),
      '#options' => array(
        'ie_null'    => t('No grid'),
        'ie770'  => t('770px grid'),
        'ie980'  => t('980px grid'),
        'ie1190' => t('1190px grid'),
        ),
      '#description' => t('Choose <em>No grid</em> if you are implementing JavaScript-based IE support for media queries. <em>See</em> the <a href="!link">Respond project on Github</a> for one JavaScript solution you can use in your theme.', array('!link' => 'https://github.com/scottjehl/Respond')),
      '#default_value' => theme_get_setting('ie_grid_select'),
    );



// Theme development tools fieldset
  $form['gridoptions'] = array(
    '#type'   => 'fieldset',
    '#title'  => t('Theme Development Tools'),
    '#weight' => '-21',
    '#description' => t('<strong>Not intended for live sites!</strong>'),
  );

    // checkbox option to display the grid
    $form['gridoptions']['showgrid'] = array(
      '#type' => 'checkbox',
      '#title' => t('Display the grid'),
      '#default_value' => theme_get_setting('showgrid'),
//      '#description' => t('While testing your own sub-theme layout, it can be helpful to display the grid.'),
    );

    // checkbox option to rebuild theme registry on every pageload
    $form['gridoptions']['squaregrid_rebuild_registry'] = array(
      '#type'          => 'checkbox',
      '#title'         => t('Rebuild theme registry on every pageload'),
      '#default_value' => theme_get_setting('squaregrid_rebuild_registry'),
      '#description'   => t('<strong>WARNING! This setting has a huge performance penalty! Turn this off before your theme goes live.</strong> <em>See <a href="!link">rebuild the theme registry</a> for more information on this</em>.', array('!link' => 'http://drupal.org/node/173880#theme-registry')),
    );

}
